@@ -27,13 +27,14 @@
  *	Author: David B. Golub, Carnegie Mellon University
  *	Date:	7/90
  */
-#include "mach_kdb.h"
+
 #if MACH_KDB
 
 /*
  * Symbol table routines for a.out format files.
  */
 
+#include <string.h>
 #include <mach/std_types.h>
 #include <machine/db_machdep.h>		/* data types */
 #include <ddb/db_sym.h>
