@@ -27,14 +27,14 @@
  *	Author: David B. Golub, Carnegie Mellon University
  *	Date:	7/90
  */
-#include "mach_kdb.h"
+
 #if MACH_KDB
 
 /*
  * Lexical analyzer.
  */
+#include <string.h>
 #include <machine/db_machdep.h>
-#include <kern/strings.h>
 #include <ddb/db_lex.h>
 
 char	db_line[DB_LEX_LINE_SIZE];
