@@ -23,9 +23,10 @@
  * any improvements or extensions that they make and grant Carnegie Mellon
  * the rights to redistribute these changes.
  */
-#include "mach_kdb.h"
+
 #if MACH_KDB
 
+#include <string.h>
 #include <kern/thread.h>
 
 #include <machine/db_machdep.h>
