@@ -28,13 +28,13 @@
  *	Date:	7/90
  */
 
-#include "mach_kdb.h"
 #if MACH_KDB
 
 /*
  * Printf and character output for debugger.
  */
 
+#include <kern/printf.h>
 #include <stdarg.h>
 #include <mach/boolean.h>
 #include <machine/db_machdep.h>
@@ -202,11 +202,6 @@ void db_end_line()
 	    db_printf("\n");
 }
 
-/*
- * Printing
- */
-extern void	_doprnt();
-
 /*VARARGS1*/
 void
 db_printf(const char *fmt, ...)
