@@ -28,14 +28,13 @@
  *	Date:	7/90
  */
 
-#include "mach_kdb.h"
 #if MACH_KDB
 
 /*
  * Miscellaneous printing.
  */
+#include <string.h>
 #include <mach/port.h>
-#include <kern/strings.h>
 #include <kern/task.h>
 #include <kern/thread.h>
 #include <kern/queue.h>
