@@ -28,11 +28,10 @@
  *	Date:	7/90
  */
 
-#include "mach_kdb.h"
 #if MACH_KDB
 
+#include <string.h>
 #include <mach/std_types.h>
-#include <kern/strings.h>
 #include <machine/db_machdep.h>
 #include <ddb/db_sym.h>
 #include <ddb/db_task_thread.h>
