@@ -28,7 +28,8 @@
  *	Date: 	3/89
  */
 
-#include <norma_device.h>
+#include <kern/printf.h>
+#include <string.h>
 
 #include <mach/boolean.h>
 #include <mach/kern_return.h>
@@ -43,6 +44,8 @@
 
 #include <kern/ast.h>
 #include <kern/counters.h>
+#include <kern/debug.h>
+#include <kern/printf.h>
 #include <kern/queue.h>
 #include <kern/zalloc.h>
 #include <kern/thread.h>
@@ -60,15 +63,12 @@
 #include <device/ds_routines.h>
 #include <device/net_status.h>
 #include <device/device_port.h>
-#include "device_reply.h"
+#include <device/device_reply.user.h>
 
 #include <machine/machspl.h>
 
 #ifdef i386
 #include <i386at/device_emul.h>
-#ifdef LINUX_DEV
-#include <i386/linux/device-drivers.h>
-#endif
 #endif
 
 #ifdef i386
@@ -109,7 +109,6 @@ ds_device_open(open_port, reply_port, reply_port_type,
 	register mach_device_t	device;
 	register kern_return_t	result;
 	register io_req_t	ior;
-	char			namebuf[64];
 	ipc_port_t		notify;
 
 #ifndef i386
@@ -128,42 +127,6 @@ ds_device_open(open_port, reply_port, reply_port_type,
 	    return (MIG_NO_REPLY);	/* no sense in doing anything */
 	}
 
-#if	NORMA_DEVICE
-	/*
-	 * Map global device name to <node> + local device name.
-	 */
-	if (name[0] != '<') {
-		extern char *dev_forward_name();
-
-		name = dev_forward_name(name, namebuf, sizeof(namebuf));
-	}
-	/*
-	 * Look for explicit node specifier, e.g., <2>sd0a.
-	 * If found, then forward request to correct device server.
-	 * If not found, then remove '<n>' and process locally.
-	 *
-	 * XXX should handle send-right reply_port as well as send-once XXX
-	 */
-	if (name[0] == '<') {
-		char *n;
-		int node = 0;
-
-		for (n = &name[1]; *n != '>'; n++) {
-			if (*n >= '0' && *n <= '9') {
-				node = 10 * node + (*n - '0');
-			} else {
-				return (D_NO_SUCH_DEVICE);
-			}
-		}
-		if (node == node_self()) {
-			name = &n[1];	/* skip trailing '>' */
-		} else {
-			forward_device_open_send(remote_device(node),
-						 reply_port, mode, name);
-			return (MIG_NO_REPLY);
-		}
-	}
-#endif	NORMA_DEVICE
 #endif	/* ! i386 */
 
 	/*
@@ -659,7 +622,7 @@ device_write_get(ior, wait)
 	if (ior->io_op & IO_INBAND) {
 	    assert(ior->io_count <= sizeof (io_buf_ptr_inband_t));
 	    new_addr = zalloc(io_inband_zone);
-	    bcopy((void*)ior->io_data, (void*)new_addr, ior->io_count);
+	    memcpy((void*)new_addr, ior->io_data, ior->io_count);
 	    ior->io_data = (io_buf_ptr_t)new_addr;
 	    ior->io_alloc_size = sizeof (io_buf_ptr_inband_t);
 
@@ -896,7 +859,7 @@ ds_device_read(device, reply_port, reply_port_type, mode, recnum,
 #ifdef lint
 	*data = *data;
 	*data_count = *data_count;
-#endif lint
+#endif /* lint */
 
 #ifndef i386
 	/*
@@ -996,7 +959,7 @@ ds_device_read_inband(device, reply_port, reply_port_type, mode, recnum,
 #ifdef lint
 	*data = *data;
 	*data_count = *data_count;
-#endif lint
+#endif /* lint */
 
 #ifndef i386
 	/*
@@ -1124,9 +1087,9 @@ boolean_t ds_read_done(ior)
 	 * Zero memory that the device did not fill.
 	 */
 	if (start_sent < start_data)
-	    bzero((char *)start_sent, start_data - start_sent);
+	    memset((char *)start_sent, 0, start_data - start_sent);
 	if (end_sent > end_data)
-	    bzero((char *)end_data, end_sent - end_data);
+	    memset((char *)end_data, 0, end_sent - end_data);
 
 
 	/*
@@ -1332,7 +1295,7 @@ ds_device_map(device, protection, offset, size, pager, unmap)
 
 #ifdef	lint
 	unmap = unmap;
-#endif	lint
+#endif	/* lint */
 	if (protection & ~VM_PROT_ALL)
 		return (KERN_INVALID_ARGUMENT);
 
