@@ -27,11 +27,8 @@
  * Interface to new debugger.
  */
 
-#include "mach_kdb.h"
 #if MACH_KDB
 
-#include <cpus.h>
-
 #include <sys/reboot.h>
 #include <vm/pmap.h>
 
@@ -41,6 +38,7 @@
 #include <i386/trap.h>
 #include <i386/setjmp.h>
 #include <i386/pmap.h>
+#include <i386/proc_reg.h>
 #include "gdt.h"
 #include "trap.h"
 
