@@ -24,9 +24,10 @@
  * the rights to redistribute these changes.
  */
 
-#include "mach_kdb.h"
 #if MACH_KDB
 
+#include <string.h>
+
 #include <mach/boolean.h>
 #include <vm/vm_map.h>
 #include <kern/thread.h>
@@ -672,4 +673,4 @@ void db_all_cprocs(
 
 #endif	/* CTHREADS_SUPPORT */
 
-#endif MACH_KDB
+#endif /* MACH_KDB */
