@@ -26,21 +26,23 @@
 /*
  * Support for 80387 floating point or FP emulator.
  */
-#include <cpus.h>
-#include <fpe.h>
-#include <platforms.h>
+
+#include <string.h>
 
 #include <mach/exception.h>
 #include <mach/machine/thread_status.h>
 #include <mach/machine/fp_reg.h>
 
+#include <kern/debug.h>
 #include <machine/machspl.h>	/* spls */
 #include <kern/mach_param.h>
+#include <kern/printf.h>
 #include <kern/thread.h>
 #include <kern/zalloc.h>
 
 #include <i386/thread.h>
 #include <i386/fpu.h>
+#include <i386/pio.h>
 #include "cpu_number.h"
 
 #if 0
@@ -265,7 +267,7 @@ ASSERT_IPL(SPL0);
 	    /*
 	     * Ensure that reserved parts of the environment are 0.
 	     */
-	    bzero((char *)&ifps->fp_save_state, sizeof(struct i386_fp_save));
+	    memset(&ifps->fp_save_state, 0, sizeof(struct i386_fp_save));
 
 	    ifps->fp_save_state.fp_control = user_fp_state->fp_control;
 	    ifps->fp_save_state.fp_status  = user_fp_state->fp_status;
@@ -293,13 +295,13 @@ ASSERT_IPL(SPL0);
 			>> FPS_TOS_SHIFT;	/* physical register
 						   for st(0) */
 		if (i == 0)
-		    bcopy(src, dst, 8 * 10);
+		    memcpy(dst, src, 8 * 10);
 		else {
-		    bcopy(src,
-			  dst + 10 * i,
+		    memcpy(dst + 10 * i,
+			  src, 
 			  10 * (8 - i));
-		    bcopy(src + 10 * (8 - i),
-			  dst,
+		    memcpy(dst, 
+			  src + 10 * (8 - i),
 			  10 * i);
 		}
 	    }
@@ -342,7 +344,7 @@ ASSERT_IPL(SPL0);
 	     * No valid floating-point state.
 	     */
 	    simple_unlock(&pcb->lock);
-	    bzero((char *)state, sizeof(struct i386_float_state));
+	    memset(state, 0, sizeof(struct i386_float_state));
 	    return KERN_SUCCESS;
 	}
 
@@ -375,7 +377,7 @@ ASSERT_IPL(SPL0);
 	    /*
 	     * Ensure that reserved parts of the environment are 0.
 	     */
-	    bzero((char *)user_fp_state,  sizeof(struct i386_fp_save));
+	    memset(user_fp_state,  0, sizeof(struct i386_fp_save));
 
 	    user_fp_state->fp_control = ifps->fp_save_state.fp_control;
 	    user_fp_state->fp_status  = ifps->fp_save_state.fp_status;
@@ -403,13 +405,13 @@ ASSERT_IPL(SPL0);
 			>> FPS_TOS_SHIFT;	/* physical register
 						   for st(0) */
 		if (i == 0)
-		    bcopy(src, dst, 8 * 10);
+		    memcpy(dst, src, 8 * 10);
 		else {
-		    bcopy(src + 10 * i,
-			  dst,
+		    memcpy(dst, 
+			  src + 10 * i,
 			  10 * (8 - i));
-		    bcopy(src,
-			  dst + 10 * (8 - i),
+		    memcpy(dst + 10 * (8 - i), 
+			  src, 
 			  10 * i);
 		}
 	    }
@@ -457,6 +459,7 @@ ASSERT_IPL(SPL0);
 /*
  * Coprocessor not present.
  */
+void
 fpnoextflt()
 {
 	/*
@@ -500,6 +503,7 @@ ASSERT_IPL(SPL0);
  * FPU overran end of segment.
  * Re-initialize FPU.  Floating point state is not valid.
  */
+void
 fpextovrflt()
 {
 	register thread_t	thread = current_thread();
@@ -551,6 +555,7 @@ fpextovrflt()
 /*
  * FPU error. Called by AST.
  */
+void
 fpexterrflt()
 {
 	register thread_t	thread = current_thread();
@@ -610,6 +615,7 @@ ASSERT_IPL(SPL0);
  * .	if called from fpnoextflt or fp_intr, we are single-cpu
  * .	otherwise, thread is running.
  */
+void
 fp_save(thread)
 	register thread_t	thread;
 {
@@ -628,6 +634,7 @@ fp_save(thread)
  *
  * Locking not needed; always called on the current thread.
  */
+void
 fp_load(thread)
 	register thread_t	thread;
 {
@@ -638,7 +645,7 @@ ASSERT_IPL(SPL0);
 	ifps = pcb->ims.ifps;
 	if (ifps == 0) {
 	    ifps = (struct i386_fpsave_state *) zalloc(ifps_zone);
-	    bzero(ifps, sizeof *ifps);
+	    memset(ifps, 0, sizeof *ifps);
 	    pcb->ims.ifps = ifps;
 	    fpinit();
 #if 1
@@ -684,7 +691,7 @@ fp_state_alloc()
 	struct i386_fpsave_state *ifps;
 
 	ifps = (struct i386_fpsave_state *)zalloc(ifps_zone);
-	bzero(ifps, sizeof *ifps);
+	memset(ifps, 0, sizeof *ifps);
 	pcb->ims.ifps = ifps;
 
 	ifps->fp_valid = TRUE;
@@ -695,11 +702,12 @@ fp_state_alloc()
 	ifps->fp_save_state.fp_tag = 0xffff;	/* all empty */
 }
 
-#if	AT386 || PS2
+#if	AT386
 /*
  *	Handle a coprocessor error interrupt on the AT386.
  *	This comes in on line 5 of the slave PIC at SPL1.
  */
+void
 fpintr()
 {
 	spl_t	s;
@@ -760,4 +768,4 @@ ASSERT_IPL(SPL1);
 	ast_on(cpu_number(), AST_I386_FP);
 	splx(s);
 }
-#endif	/* AT386 || PS2 */
+#endif	/* AT386 */
