@@ -24,8 +24,7 @@
  * the rights to redistribute these changes.
  */
 
-#include <cpus.h>
-#include <mach_debug.h>
+#include <string.h>
 
 #include <mach/std_types.h>
 #include <mach/kern_return.h>
@@ -34,6 +33,7 @@
 
 #include "vm_param.h"
 #include <kern/counters.h>
+#include <kern/debug.h>
 #include <kern/mach_param.h>
 #include <kern/thread.h>
 #include <kern/sched_prim.h>
@@ -50,6 +50,7 @@
 #include "gdt.h"
 #include "ldt.h"
 #include "ktss.h"
+#include "pcb.h"
 
 #if	NCPUS > 1
 #include <i386/mp_desc.h>
@@ -124,8 +125,8 @@ vm_offset_t stack_detach(thread)
 #define	curr_gdt(mycpu)		(mp_gdt[mycpu])
 #define	curr_ktss(mycpu)	(mp_ktss[mycpu])
 #else
-#define	curr_gdt(mycpu)		(gdt)
-#define	curr_ktss(mycpu)	(&ktss)
+#define	curr_gdt(mycpu)		((void)(mycpu), gdt)
+#define	curr_ktss(mycpu)	((void)(mycpu), &ktss)
 #endif
 
 #define	gdt_desc_p(mycpu,sel) \
@@ -192,6 +193,13 @@ void switch_ktss(pcb)
 	    set_ldt(USER_LDT);
 	}
     }
+
+    /* Copy in the per-thread GDT slots.  No reloading is necessary
+       because just restoring the segment registers on the way back to
+       user mode reloads the shadow registers from the in-memory GDT.  */
+    memcpy (gdt_desc_p (mycpu, USER_GDT),
+        pcb->ims.user_gdt, sizeof pcb->ims.user_gdt);
+
 	/*
 	 * Load the floating-point context, if necessary.
 	 */
@@ -327,7 +335,7 @@ void pcb_init(thread)
 	/*
 	 *	We can't let random values leak out to the user.
 	 */
-	bzero((char *) pcb, sizeof *pcb);
+	memset(pcb, 0, sizeof *pcb);
 	simple_lock_init(&pcb->lock);
 
 	/*
@@ -398,6 +406,8 @@ kern_return_t thread_setstatus(thread, flavor, tstate, count)
 		    return(KERN_INVALID_ARGUMENT);
 		}
 
+		state = (struct i386_thread_state *) tstate;
+
 		if (flavor == i386_REGS_SEGS_STATE) {
 		    /*
 		     * Code and stack selectors must not be null,
@@ -416,8 +426,6 @@ kern_return_t thread_setstatus(thread, flavor, tstate, count)
 			return KERN_INVALID_ARGUMENT;
 		}
 
-		state = (struct i386_thread_state *) tstate;
-
 		saved_state = USER_REGS(thread);
 
 		/*
@@ -526,9 +534,9 @@ kern_return_t thread_setstatus(thread, flavor, tstate, count)
 			thread->pcb->ims.io_tss = tss;
 		}
 
-		bcopy((char *) state->pm,
-		      (char *) tss->bitmap,
-		      sizeof state->pm);
+		memcpy(tss->bitmap,
+		       state->pm,
+		       sizeof state->pm);
 #endif
 		break;
 	    }
@@ -687,9 +695,9 @@ kern_return_t thread_getstatus(thread, flavor, tstate, count)
 		     *	The thread has its own ktss.
 		     */
 
-		    bcopy((char *) tss->bitmap,
-			  (char *) state->pm,
-			  sizeof state->pm);
+		    memcpy(state->pm,
+			   tss->bitmap,
+			   sizeof state->pm);
 		}
 
 		*count = i386_ISA_PORT_MAP_STATE_COUNT;
