@@ -32,13 +32,12 @@
 #define	_I386_SEG_H_
 
 #include <mach/inline.h>
-#include <platforms.h>
 
 /*
  * i386 segmentation.
  */
 
-#ifndef ASSEMBLER
+#ifndef __ASSEMBLER__
 
 /*
  * Real segment descriptor.
@@ -61,7 +60,7 @@ struct real_gate {
 			offset_high:16;	/* offset 16..31 */
 };
 
-#endif /* !ASSEMBLER */
+#endif /* !__ASSEMBLER__ */
 
 #define	SZ_32		0x4			/* 32-bit segment */
 #define SZ_16		0x0			/* 16-bit segment */
@@ -113,7 +112,7 @@ struct real_gate {
 #define	sel_idx(sel)	((sel)>>3)
 
 
-#ifndef ASSEMBLER
+#ifndef __ASSEMBLER__
 
 #include <mach/inline.h>
 
@@ -121,20 +120,20 @@ struct real_gate {
 /* Format of a "pseudo-descriptor", used for loading the IDT and GDT.  */
 struct pseudo_descriptor
 {
-	short pad;
 	unsigned short limit;
 	unsigned long linear_base;
-};
+	short pad;
+} __attribute__((packed));
 
 
 /* Load the processor's IDT, GDT, or LDT pointers.  */
 MACH_INLINE void lgdt(struct pseudo_descriptor *pdesc)
 {
-	__asm volatile("lgdt %0" : : "m" (pdesc->limit));
+	__asm volatile("lgdt %0" : : "m" (*pdesc));
 }
 MACH_INLINE void lidt(struct pseudo_descriptor *pdesc)
 {
-	__asm volatile("lidt %0" : : "m" (pdesc->limit));
+	__asm volatile("lidt %0" : : "m" (*pdesc));
 }
 MACH_INLINE void lldt(unsigned short ldt_selector)
 {
@@ -179,6 +178,6 @@ fill_gate(struct real_gate *gate, unsigned offset, unsigned short selector,
 	gate->offset_high = (offset >> 16) & 0xffff;
 }
 
-#endif /* !ASSEMBLER */
+#endif /* !__ASSEMBLER__ */
 
 #endif	/* _I386_SEG_H_ */
