@@ -27,13 +27,9 @@
  * Hardware trap/fault handler.
  */
 
-#include <cpus.h>
-#include <fpe.h>
-#include <mach_kdb.h>
-#include <mach_ttd.h>
-#include <mach_pcsample.h>
-
 #include <sys/types.h>
+#include <string.h>
+
 #include <mach/machine/eflags.h>
 #include <i386/trap.h>
 #include <machine/machspl.h>	/* for spl_t */
@@ -47,6 +43,8 @@
 #include <vm/vm_map.h>
 
 #include <kern/ast.h>
+#include <kern/debug.h>
+#include <kern/printf.h>
 #include <kern/thread.h>
 #include <kern/task.h>
 #include <kern/sched.h>
@@ -174,7 +172,6 @@ boolean_t	brb = TRUE;
 void kernel_trap(regs)
 	register struct i386_saved_state *regs;
 {
-	int	exc;
 	int	code;
 	int	subcode;
 	register int	type;
@@ -370,8 +367,6 @@ int user_trap(regs)
 	int	code;
 	int	subcode;
 	register int	type;
-	vm_map_t	map;
-	kern_return_t	result;
 	register thread_t thread = current_thread();
 	extern vm_offset_t phys_last_addr;
 
@@ -842,7 +837,6 @@ v86_assist(thread, regs)
 		    {
 			vm_offset_t sp;
 			int	nflags;
-			int	size;
 			union iret_struct iret_struct;
 
 			v86->flags &= ~V86_IRET_PENDING;
@@ -946,9 +940,9 @@ v86_assist(thread, regs)
 #ifdef	gcc_1_36_worked
 		int_vec = ((struct int_vec *)0)[vec];
 #else
-		bcopy((char *) (sizeof(struct int_vec) * vec),
-		      (char *)&int_vec,
-		      sizeof (struct int_vec));
+		memcpy(&int_vec,
+		       (void *)(sizeof(struct int_vec) * vec),
+		       sizeof (struct int_vec));
 #endif
 		if (copyout((char *)&iret_16,
 			    (char *)Addr8086(regs->ss,sp),
