@@ -28,6 +28,8 @@
  * Each thread in a task may have its own LDT.
  */
 
+#include <string.h>
+
 #include <kern/kalloc.h>
 #include <kern/thread.h>
 
@@ -221,11 +223,11 @@ i386_set_ldt(thread, first_selector, desc_list, count, desc_list_inline)
 	     * from old to new.  Otherwise copy the default ldt.
 	     */
 	    if (old_ldt) {
-		bcopy((char *)&old_ldt->ldt[0],
-		      (char *)&new_ldt->ldt[0],
-		      old_ldt->desc.limit_low + 1);
+		memcpy(&new_ldt->ldt[0],
+		       &old_ldt->ldt[0],
+		       old_ldt->desc.limit_low + 1);
 	    }
-	    else if (thread == current_thread()) {
+	    else {
 		struct real_descriptor template = {0, 0, 0, ACC_P, 0, 0 ,0};
 
 		for (dp = &new_ldt->ldt[0], i = 0; i < first_desc; i++, dp++) {
@@ -253,9 +255,9 @@ i386_set_ldt(thread, first_selector, desc_list, count, desc_list_inline)
 	/*
 	 * Install new descriptors.
 	 */
-	bcopy((char *)desc_list,
-	      (char *)&old_ldt->ldt[first_desc],
-	      count * sizeof(struct real_descriptor));
+	memcpy(&old_ldt->ldt[first_desc],
+	       desc_list,
+	       count * sizeof(struct real_descriptor));
 
 	simple_unlock(&pcb->lock);
 
@@ -355,9 +357,9 @@ i386_get_ldt(thread, first_selector, selector_count, desc_list, count)
 	/*
 	 * copy out the descriptors
 	 */
-	bcopy((char *)&user_ldt->ldt[first_desc],
-	      (char *)*desc_list,
-	      ldt_size);
+	memcpy(*desc_list,
+	       &user_ldt->ldt[first_desc],
+	       ldt_size);
 	*count = ldt_count;
 	simple_unlock(&pcb->lock);
 
@@ -378,7 +380,7 @@ i386_get_ldt(thread, first_selector, selector_count, desc_list, count)
 	     */
 	    size_left = size_used - ldt_size;
 	    if (size_left > 0)
-		bzero((char *)addr + ldt_size, size_left);
+		memset((char *)addr + ldt_size, 0, size_left);
 
 	    /*
 	     * Make memory into copyin form - this unwires it.
@@ -399,3 +401,57 @@ user_ldt_free(user_ldt)
 		user_ldt->desc.limit_low + 1
 		+ sizeof(struct real_descriptor));
 }
+
+
+kern_return_t
+i386_set_gdt (thread_t thread, int *selector, struct real_descriptor desc)
+{
+  int idx;
+
+  if (thread == THREAD_NULL)
+    return KERN_INVALID_ARGUMENT;
+
+  if (*selector == -1)
+    {
+      for (idx = 0; idx < USER_GDT_SLOTS; ++idx)
+        if ((thread->pcb->ims.user_gdt[idx].access & ACC_P) == 0)
+          {
+            *selector = ((idx + sel_idx(USER_GDT)) << 3) | SEL_PL_U;
+            break;
+          }
+      if (idx == USER_GDT_SLOTS)
+        return KERN_NO_SPACE;   /* ? */
+    }
+  else if ((*selector & (SEL_LDT|SEL_PL)) != SEL_PL_U
+           || sel_idx (*selector) < sel_idx(USER_GDT)
+           || sel_idx (*selector) >= sel_idx(USER_GDT) + USER_GDT_SLOTS)
+    return KERN_INVALID_ARGUMENT;
+  else
+    idx = sel_idx (*selector) - sel_idx(USER_GDT);
+
+  if ((desc.access & ACC_P) == 0)
+    memset (&thread->pcb->ims.user_gdt[idx], 0,
+            sizeof thread->pcb->ims.user_gdt[idx]);
+  else if ((desc.access & (ACC_TYPE_USER|ACC_PL)) != (ACC_TYPE_USER|ACC_PL_U))
+    return KERN_INVALID_ARGUMENT;
+  else
+    thread->pcb->ims.user_gdt[idx] = desc;
+
+  return KERN_SUCCESS;
+}
+
+kern_return_t
+i386_get_gdt (thread_t thread, int selector, struct real_descriptor *desc)
+{
+  if (thread == THREAD_NULL)
+    return KERN_INVALID_ARGUMENT;
+
+  if ((selector & (SEL_LDT|SEL_PL)) != SEL_PL_U
+      || sel_idx (selector) < sel_idx(USER_GDT)
+      || sel_idx (selector) >= sel_idx(USER_GDT) + USER_GDT_SLOTS)
+    return KERN_INVALID_ARGUMENT;
+
+  *desc = thread->pcb->ims.user_gdt[sel_idx (selector) - sel_idx(USER_GDT)];
+
+  return KERN_SUCCESS;
+}
