@@ -76,9 +76,9 @@ WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
 /* $ Header:  $ */
 
-#include <mach_kdb.h>
-
 #include <sys/types.h>
+#include <kern/debug.h>
+#include <kern/printf.h>
 #include <kern/time_out.h>
 #include <device/conf.h>
 #include <device/tty.h>
@@ -86,27 +86,15 @@ WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #include <device/buf.h>		/* for struct uio (!) */
 #include <i386/io_port.h>
 #include <vm/vm_kern.h>
-#include "vm_param.h"
+#include <i386/vm_param.h>
 #include <i386/machspl.h>
+#include <i386/pio.h>
 #include <i386at/cram.h>
 #include <i386at/kd.h>
+#include <i386at/kd_event.h>
+#include <i386at/kd_mouse.h>
 #include <i386at/kdsoft.h>
-#include <cons.h>
-
-#include <blit.h>
-#if	NBLIT > 0
-#include <i386at/blitvar.h>
-#else
-#define blit_present()	FALSE
-#define blit_init()			/* nothing */
-#endif
-
-#include <evc.h>
-#if	NEVC > 0
-int evc1init();
-#else
-#define evc1init()	FALSE
-#endif
+#include <device/cons.h>
 
 #define DEBUG	1			/* export feep() */
 
@@ -358,6 +346,7 @@ io_reg_t vga_port_list[] = {
 
 mach_device_t	kd_io_device = 0;
 
+void
 kd_io_map_open(device)
 	mach_device_t	device;
 {
@@ -365,6 +354,7 @@ kd_io_map_open(device)
 	io_port_create(device, vga_port_list);
 }
 
+void
 kd_io_map_close()
 {
 	io_port_destroy(kd_io_device);
@@ -408,6 +398,7 @@ int	kd_pollc = 0;
  *	Ring the bell for a short time.
  *	Warning: uses outb(). You may prefer to use kd_debug_put.
  */
+void
 feep()
 {
 	int i;
@@ -418,6 +409,7 @@ feep()
 	kd_belloff();
 }
 
+void
 pause()
 {
 	int i;
@@ -431,6 +423,7 @@ pause()
  * LOC=0 means put it in the bottom right corner, LOC=1 means put it
  * one column to the left, etc.
  */
+void
 kd_debug_put(loc, c)
 int	loc;
 char	c;
@@ -445,6 +438,7 @@ char	c;
 extern int	mouse_in_use;
 int		old_kb_mode;
 
+void
 cnpollc(on)
 boolean_t on;
 {
@@ -486,6 +480,7 @@ boolean_t on;
  * output:	device is opened and setup
  *
  */
+int
 kdopen(dev, flag, ior)
 	dev_t	dev;
 	int	flag;
@@ -538,6 +533,7 @@ kdopen(dev, flag, ior)
  *
  */
 /*ARGSUSED*/
+void
 kdclose(dev, flag)
 int	dev;
 int	flag;
@@ -572,6 +568,7 @@ int	flag;
  *
  */
 /*ARGSUSED*/
+int
 kdread(dev, uio)
 int	dev;
 struct	uio	*uio;
@@ -596,6 +593,7 @@ struct	uio	*uio;
  *
  */
 /*ARGSUSED*/
+int
 kdwrite(dev, uio)
 int	dev;
 struct	uio	*uio;
@@ -621,6 +619,7 @@ kdmmap(dev, off, prot)
 	return(i386_btop(kd_bitmap_start+off));
 }
 
+int
 kdportdeath(dev, port)
 	dev_t	dev;
 	mach_port_t	port;
@@ -695,6 +694,7 @@ io_return_t kdsetstat(dev, flavor, data, count)
  *	Turn the bell on or off.  Returns error code, if given bogus
  *	on/off value.
  */
+int
 kdsetbell(val, flags)
 int	val;				/* on or off */
 int	flags;				/* flags set for console */
@@ -718,6 +718,7 @@ int	flags;				/* flags set for console */
  *
  *	Get entry from key mapping table.  Returns error code, if any.
  */
+int
 kdgetkbent(kbent)
 struct kbentry *	kbent;
 {
@@ -770,6 +771,7 @@ int	flags;				/* flags set for console */
  *
  */
 /*ARGSUSED*/
+int
 kdintr(vec, regs)
 int	vec;
 int	regs;
@@ -777,7 +779,6 @@ int	regs;
 	struct	tty	*tp;
 	unsigned char	c;
 	unsigned char	scancode;
-	int		o_pri;
 	int		char_idx;
 	boolean_t	up = FALSE;		/* key-up event */
 	extern int	mouse_in_use;
@@ -909,6 +910,7 @@ int	regs;
  *	For pending commands, complete the command.  For data bytes,
  *	drop the ack on the floor.
  */
+void
 kd_handle_ack()
 {
 	switch (kd_ack) {
@@ -933,6 +935,7 @@ kd_handle_ack()
  *
  *	Resend a missed keyboard command or data byte.
  */
+void
 kd_resend()
 {
 	if (kd_ack == NOT_WAITING)
@@ -953,6 +956,7 @@ kd_resend()
  *
  * output:	the new state
  */
+int
 do_modifier(state, c, up)
 int	state;
 Scancode	c;
@@ -1075,6 +1079,7 @@ int		*regs;
  *	Return the value for the 2nd index into key_map that
  *	corresponds to the given state.
  */
+int
 kdstate2idx(state, extended)
 int	state;				/* bit vector, not a state index */
 boolean_t	extended;
@@ -1114,6 +1119,7 @@ boolean_t	extended;
  * Entered and left at spltty.  Drops priority to spl0 to display character.
  * ASSUMES that it is never called from interrupt-driven code.
  */
+int
 kdstart(tp)
 struct	tty	*tp;
 {
@@ -1164,6 +1170,7 @@ struct	tty	*tp;
 }
 
 /*ARGSUSED*/
+int
 kdstop(tp, flags)
 	register struct tty *tp;
 	int	flags;
@@ -1190,6 +1197,7 @@ kdstop(tp, flags)
  * output	: Driver is initialized
  *
  */
+void
 kdinit()
 {
 	void	kd_xga_init();
@@ -1207,11 +1215,7 @@ kdinit()
 	 * board specific initialization: set up globals and kd_dxxx
 	 * pointers, and synch displayed cursor with logical cursor.
 	 */
-	if (!evc1init())
-	  if (blit_present())
-		blit_init();
-	  else
-		kd_xga_init();
+	kd_xga_init();
 
 	/* get rid of any garbage in output buffer */
 	if (inb(K_STATUS) & K_OBUF_FUL)
@@ -1244,6 +1248,9 @@ kdinit()
 					   enable the keyboard controller.
 					   This keeps NUM-LOCK from being
 					   set on the NEC Versa. */
+
+	/* Allocate the input buffer.  */
+	ttychars(&kd_tty);
 }
 
 /*
@@ -1257,6 +1264,8 @@ kdinit()
  *
  */
 static unsigned int kd_bellstate = 0;
+
+void
 kd_belloff()
 {
 	unsigned char status;
@@ -1277,6 +1286,7 @@ kd_belloff()
  * output	: bell is turned on
  *
  */
+void
 kd_bellon()
 {
 	unsigned char	status;
@@ -1306,6 +1316,7 @@ kd_bellon()
  */
 int sit_for_0 = 1;
 
+void
 kd_putc(ch)
 u_char	ch;
 {
@@ -1359,6 +1370,7 @@ u_char	ch;
  *		  screen.
  *
  */
+void
 kd_setpos(newpos)
 csrpos_t newpos;
 {
@@ -1385,6 +1397,7 @@ csrpos_t newpos;
  * output	: lines on screen appear to be shifted up one line
  *
  */
+void
 kd_scrollup()
 {
 	csrpos_t to;
@@ -1414,6 +1427,7 @@ kd_scrollup()
  * output	: Lines on screen appear to be moved down one line
  *
  */
+void
 kd_scrolldn()
 {
 	csrpos_t to;
@@ -1447,6 +1461,7 @@ kd_scrolldn()
  *		  defined by the ansi terminal specification
  *
  */
+void
 kd_parseesc()
 {
 	u_char	*escp;
@@ -1518,6 +1533,7 @@ unsigned char color_table[] = { 0, 4, 2, 6, 1, 5, 3, 7,
  *	 	  sequence acceptable to the ansi terminal specification
  *
  */
+void
 kd_parserest(cp)
 u_char	*cp;
 {
@@ -1813,6 +1829,7 @@ int	*nump;
 	return(cp - original);
 }
 
+void
 kd_tab()
 {
     int i;
@@ -1833,6 +1850,7 @@ kd_tab()
  * output	: Screen is cleared
  *
  */
+void
 kd_cls()
 {
 	(*kd_dclear)(0, ONE_PAGE/ONE_SPACE, kd_attr);
@@ -1850,6 +1868,7 @@ kd_cls()
  * output	: Cursor position is moved
  *
  */
+void
 kd_home()
 {
 	kd_setpos(0);
@@ -1866,6 +1885,7 @@ kd_home()
  * output	: Cursor moves up one line, or screen is scrolled
  *
  */
+void
 kd_up()
 {
 	if (kd_curpos < ONE_LINE)
@@ -1885,6 +1905,7 @@ kd_up()
  * output	: Cursor moves down one line or the screen is scrolled
  *
  */
+void
 kd_down()
 {
 	if (kd_curpos >= (ONE_PAGE - ONE_LINE))
@@ -1904,6 +1925,7 @@ kd_down()
  * output	: Cursor moves one position to the right
  *
  */
+void
 kd_right()
 {
 	if (kd_curpos < (ONE_PAGE - ONE_SPACE))
@@ -1925,6 +1947,7 @@ kd_right()
  * output	: Cursor moves one position to the left
  *
  */
+void
 kd_left()
 {
 	if (0 < kd_curpos)
@@ -1943,6 +1966,7 @@ kd_left()
  * output	: Cursor moves to the beginning of the current line
  *
  */
+void
 kd_cr()
 {
 	kd_setpos(BEG_OF_LINE(kd_curpos));
@@ -1960,6 +1984,7 @@ kd_cr()
  * output	: Screen is cleared from current cursor postion to bottom
  *
  */
+void
 kd_cltobcur()
 {
 	csrpos_t start;
@@ -1982,6 +2007,7 @@ kd_cltobcur()
  * output	: Screen is cleared from current cursor postion to top
  *
  */
+void
 kd_cltopcur()
 {
 	int	count;
@@ -2001,6 +2027,7 @@ kd_cltopcur()
  * output	: Line is cleared from current cursor position to eoln
  *
  */
+void
 kd_cltoecur()
 {
 	csrpos_t i;
@@ -2023,6 +2050,7 @@ kd_cltoecur()
  * output	: Line is cleared from beginning to current position
  *
  */
+void
 kd_clfrbcur()
 {
 	csrpos_t i;
@@ -2043,6 +2071,7 @@ kd_clfrbcur()
  * output	: lines appear to be deleted
  *
  */
+void
 kd_delln(number)
 int	number;
 {
@@ -2081,6 +2110,7 @@ int	number;
  * output	: New lines appear to be inserted
  *
  */
+void
 kd_insln(number)
 int	number;
 {
@@ -2120,6 +2150,7 @@ int	number;
  * output	: characters appear to be deleted
  *
  */
+void
 kd_delch(number)
 int	number;
 {
@@ -2161,6 +2192,7 @@ int	number;
  * output	: characters appear to be blanked or erased
  *
  */
+void
 kd_erase(number)
 int	number;
 {
@@ -2186,6 +2218,7 @@ int	number;
  * output	: Current line is erased
  *
  */
+void
 kd_eraseln()
 {
 	csrpos_t i;
@@ -2209,6 +2242,7 @@ kd_eraseln()
  * output	: Blanks are inserted at cursor position
  *
  */
+void
 kd_insch(number)
 int	number;
 {
@@ -2250,6 +2284,7 @@ int	number;
  *		  returns TRUE if character is lowercase
  *
  */
+boolean_t
 kd_isupper(c)
 u_char	c;
 {
@@ -2258,6 +2293,7 @@ u_char	c;
 	return(FALSE);
 }
 
+boolean_t
 kd_islower(c)
 u_char	c;
 {
@@ -2275,6 +2311,7 @@ u_char	c;
  *	keyboard command.
  *
  */
+void
 kd_senddata(ch)
 unsigned char	ch;
 {
@@ -2292,6 +2329,7 @@ unsigned char	ch;
  *	clear before sending the data.
  *
  */
+void
 kd_sendcmd(ch)
 unsigned char	ch;
 {
@@ -2315,6 +2353,7 @@ kd_getdata()
 	return(inb(K_RDWR));
 }
 
+unsigned char
 kd_cmdreg_read()
 {
 int ch=KC_CMD_READ;
@@ -2326,6 +2365,7 @@ int ch=KC_CMD_READ;
 	return(inb(K_RDWR));
 }
 
+void
 kd_cmdreg_write(val)
 {
 int ch=KC_CMD_WRITE;
@@ -2337,6 +2377,7 @@ int ch=KC_CMD_WRITE;
 	outb(K_RDWR, val);
 }
 
+void
 kd_mouse_drain()
 {
 	int i;
@@ -2350,7 +2391,7 @@ kd_mouse_drain()
  *
  *	Set kd_state and update the keyboard status LEDs.
  */
-
+void
 set_kd_state(newstate)
 int newstate;
 {
@@ -2382,6 +2423,7 @@ int	state;
  *
  *	Set the keyboard LEDs according to the given byte.
  */
+void
 kd_setleds1(val)
 u_char val;
 {
@@ -2395,6 +2437,7 @@ u_char val;
 	kd_senddata(K_CMD_LEDS);
 }
 
+void
 kd_setleds2()
 {
 	kd_senddata(kd_nextled);
@@ -2408,6 +2451,7 @@ kd_setleds2()
  *	Currently disabled because cngetc ignores caps lock and num
  *	lock anyway.
  */
+void
 cnsetleds(val)
 u_char val;
 {
@@ -2417,6 +2461,7 @@ u_char val;
 	(void)kd_getdata();		/* XXX - assume is ACK */
 }
 
+void
 kdreboot()
 {
 	(*kd_dreset)();
@@ -2435,6 +2480,7 @@ kdreboot()
 static int which_button[] = {0, MOUSE_LEFT, MOUSE_MIDDLE, MOUSE_RIGHT};
 static struct mouse_motion moved;
 
+int
 kd_kbd_magic(scancode)
 {
 int new_button = 0;
@@ -2988,8 +3034,6 @@ kdcngetc(dev_t dev, int wait)
 int
 kdcnputc(dev_t dev, int c)
 {
-	int	i;
-
 	if (!kd_initialized)
 		return;
 
