@@ -35,13 +35,14 @@
 #ifndef	_PMAP_MACHINE_
 #define _PMAP_MACHINE_	1
 
-#ifndef	ASSEMBLER
+#ifndef	__ASSEMBLER__
 
 #include <kern/zalloc.h>
 #include <kern/lock.h>
 #include <mach/machine/vm_param.h>
 #include <mach/vm_statistics.h>
 #include <mach/kern_return.h>
+#include <i386/proc_reg.h>
 
 /*
  *	Define the generic in terms of the specific
@@ -58,26 +59,15 @@
 #define round_intel_to_vm(x)	round_i386_to_vm(x)
 #define vm_to_intel(x)		vm_to_i386(x)
 #endif	/* i386 */
-#if	i860
-#define	INTEL_PGBYTES		I860_PGBYTES
-#define INTEL_PGSHIFT		I860_PGSHIFT
-#define	intel_btop(x)		i860_btop(x)
-#define	intel_ptob(x)		i860_ptob(x)
-#define	intel_round_page(x)	i860_round_page(x)
-#define	intel_trunc_page(x)	i860_trunc_page(x)
-#define trunc_intel_to_vm(x)	trunc_i860_to_vm(x)
-#define round_intel_to_vm(x)	round_i860_to_vm(x)
-#define vm_to_intel(x)		vm_to_i860(x)
-#endif	/* i860 */
 
 /*
- *	i386/i486/i860 Page Table Entry
+ *	i386/i486 Page Table Entry
  */
 
 typedef unsigned int	pt_entry_t;
 #define PT_ENTRY_NULL	((pt_entry_t *) 0)
 
-#endif	/* ASSEMBLER */
+#endif	/* __ASSEMBLER__ */
 
 #define INTEL_OFFMASK	0xfff	/* offset within page */
 #define PDESHIFT	22	/* page descriptor shift */
@@ -108,11 +98,7 @@ typedef unsigned int	pt_entry_t;
  *	without using the bit fields).
  */
 
-#if	i860
-#define INTEL_PTE_valid		0x00000001
-#else
 #define INTEL_PTE_VALID		0x00000001
-#endif
 #define INTEL_PTE_WRITE		0x00000002
 #define INTEL_PTE_USER		0x00000004
 #define INTEL_PTE_WTHRU		0x00000008
@@ -122,22 +108,6 @@ typedef unsigned int	pt_entry_t;
 #define INTEL_PTE_WIRED		0x00000200
 #define INTEL_PTE_PFN		0xfffff000
 
-#if	i860
-#if	NOCACHE
-#define	INTEL_PTE_VALID		(INTEL_PTE_valid	\
-				|INTEL_PTE_WTHRU	\
-				|INTEL_PTE_NCACHE	\
-				|INTEL_PTE_REF		\
-				|INTEL_PTE_MOD		\
-				)
-#else	/* NOCACHE */
-#define	INTEL_PTE_VALID		(INTEL_PTE_valid	\
-				|INTEL_PTE_REF		\
-				|INTEL_PTE_MOD		\
-				)
-#endif	/* NOCACHE */
-#endif	/* i860 */
-
 #define	pa_to_pte(a)		((a) & INTEL_PTE_PFN)
 #define	pte_to_pa(p)		((p) & INTEL_PTE_PFN)
 #define	pte_increment_pa(p)	((p) += INTEL_OFFMASK+1)
@@ -147,7 +117,7 @@ typedef unsigned int	pt_entry_t;
  */
 #define ptetokv(a)	(phystokv(pte_to_pa(a)))
 
-#ifndef	ASSEMBLER
+#ifndef	__ASSEMBLER__
 typedef	volatile long	cpu_set;	/* set of CPUs - must be <= 32 */
 					/* changed by other processors */
 
@@ -164,11 +134,7 @@ typedef struct pmap	*pmap_t;
 
 #define PMAP_NULL	((pmap_t) 0)
 
-#if	i860
-/*#define	set_dirbase(dirbase)	flush_and_ctxsw(dirbase)*//*akp*/
-#else
 #define	set_dirbase(dirbase)	set_cr3(dirbase)
-#endif
 
 #if	NCPUS > 1
 /*
@@ -202,7 +168,7 @@ extern	pmap_t	kernel_pmap;
 #endif	/* NCPUS > 1 */
 
 /*
- *	Machine dependent routines that are used only for i386/i486/i860.
+ *	Machine dependent routines that are used only for i386/i486.
  */
 
 pt_entry_t *pmap_pte(pmap_t pmap, vm_offset_t addr);
@@ -396,6 +362,6 @@ pt_entry_t *pmap_pte(pmap_t pmap, vm_offset_t addr);
 #define	pmap_attribute(pmap,addr,size,attr,value) \
 					(KERN_INVALID_ADDRESS)
 
-#endif	/* ASSEMBLER */
+#endif	/* __ASSEMBLER__ */
 
 #endif	/* _PMAP_MACHINE_ */
