@@ -31,7 +31,7 @@
  *	Functions to manipulate IPC objects.
  */
 
-#include <mach_ipc_compat.h>
+#include <string.h>
 
 #include <mach/boolean.h>
 #include <mach/kern_return.h>
@@ -45,6 +45,8 @@
 #include <ipc/ipc_right.h>
 #include <ipc/ipc_notify.h>
 #include <ipc/ipc_pset.h>
+#include <kern/debug.h>
+#include <kern/printf.h>
 
 zone_t ipc_object_zones[IOT_NUMBER];
 
@@ -241,11 +243,11 @@ ipc_object_alloc(
 	if (otype == IOT_PORT) {
 		ipc_port_t port = (ipc_port_t)object;
 
-		bzero((char *)port, sizeof(*port));
+		memset(port, 0, sizeof(*port));
 	} else if (otype == IOT_PORT_SET) {
 		ipc_pset_t pset = (ipc_pset_t)object;
 
-		bzero((char *)pset, sizeof(*pset));
+		memset(pset, 0, sizeof(*pset));
 	}
 	kr = ipc_entry_alloc(space, namep, &entry);
 	if (kr != KERN_SUCCESS) {
@@ -307,11 +309,11 @@ ipc_object_alloc_name(
 	if (otype == IOT_PORT) {
 		ipc_port_t port = (ipc_port_t)object;
 
-		bzero((char *)port, sizeof(*port));
+		memset(port, 0, sizeof(*port));
 	} else if (otype == IOT_PORT_SET) {
 		ipc_pset_t pset = (ipc_pset_t)object;
 
-		bzero((char *)pset, sizeof(*pset));
+		memset(pset, 0, sizeof(*pset));
 	}
 
 	kr = ipc_entry_alloc_name(space, name, &entry);
@@ -1280,8 +1282,6 @@ ipc_object_copyout_name_compat(space, object, msgt_name, name)
 
 #endif	/* MACH_IPC_COMPAT */
 
-#include <mach_kdb.h>
-
 
 #if	MACH_KDB
 #define	printf	kdbprintf
