@@ -33,7 +33,7 @@
  *	Exported kernel calls.  See mach_debug/mach_debug.defs.
  */
 
-#include <mach_ipc_compat.h>
+#include <string.h>
 
 #include <mach/kern_return.h>
 #include <mach/port.h>
@@ -455,7 +455,7 @@ mach_port_space_info(
 				  table_size - rsize_used);
 
 		if (size_used != rsize_used)
-			bzero((char *) (table_addr + size_used),
+			memset((char *) (table_addr + size_used), 0, 
 			      rsize_used - size_used);
 
 		kr = vm_map_copyin(ipc_kernel_map, table_addr, rsize_used,
@@ -490,7 +490,7 @@ mach_port_space_info(
 				  tree_size - rsize_used);
 
 		if (size_used != rsize_used)
-			bzero((char *) (tree_addr + size_used),
+			memset((char *) (tree_addr + size_used), 0, 
 			      rsize_used - size_used);
 
 		kr = vm_map_copyin(ipc_kernel_map, tree_addr, rsize_used,
