@@ -36,15 +36,14 @@
  *	Exported message traps.  See mach/message.h.
  */
 
-#include <mach_ipc_compat.h>
-#include <norma_ipc.h>
-
 #include <mach/kern_return.h>
 #include <mach/port.h>
 #include <mach/message.h>
 #include <kern/assert.h>
 #include <kern/counters.h>
+#include <kern/debug.h>
 #include <kern/lock.h>
+#include <kern/printf.h>
 #include <kern/sched_prim.h>
 #include <kern/ipc_sched.h>
 #include <vm/vm_map.h>
@@ -59,8 +58,8 @@
 #include <ipc/ipc_thread.h>
 #include <ipc/ipc_entry.h>
 #include <ipc/mach_msg.h>
-
-
+#include <machine/locore.h>
+#include <machine/pcb.h>
 
 extern void exception_raise_continue();
 extern void exception_raise_continue_fast();
@@ -635,14 +634,6 @@ mach_msg_trap(msg, option, send_size, rcv_size, rcv_name, time_out, notify)
 				goto kernel_send;
 			}
 
-#if	NORMA_IPC
-			if (IP_NORMA_IS_PROXY(dest_port)) {
-				ip_unlock(dest_port);
-				ip_unlock(reply_port);
-				goto norma_send;
-		        }
-#endif	/* NORMA_IPC */
-
 			if (dest_port->ip_msgcount >= dest_port->ip_qlimit)
 				goto abort_request_send_receive;
 
@@ -754,13 +745,6 @@ mach_msg_trap(msg, option, send_size, rcv_size, rcv_name, time_out, notify)
 			/* make sure we can queue to the destination */
 
 			assert(dest_port->ip_receiver != ipc_space_kernel);
-#if	NORMA_IPC
-			if (IP_NORMA_IS_PROXY(dest_port)) {
-				is_write_unlock(space);
-				ip_unlock(dest_port);
-				goto norma_send;
-			}
-#endif	/* NORMA_IPC */
 
 			/* optimized ipc_entry_lookup/ipc_mqueue_copyin */
 
@@ -859,9 +843,6 @@ mach_msg_trap(msg, option, send_size, rcv_size, rcv_name, time_out, notify)
 
 		assert(ip_active(dest_port));
 		assert(dest_port->ip_receiver != ipc_space_kernel);
-#if	NORMA_IPC
-		assert(! IP_NORMA_IS_PROXY(dest_port));
-#endif	/* NORMA_IPC */
 		assert((dest_port->ip_msgcount < dest_port->ip_qlimit) ||
 		       (MACH_MSGH_BITS_REMOTE(kmsg->ikm_header.msgh_bits) ==
 						MACH_MSG_TYPE_PORT_SEND_ONCE));
@@ -1341,9 +1322,6 @@ mach_msg_trap(msg, option, send_size, rcv_size, rcv_name, time_out, notify)
 		}
 
 		if (ip_active(dest_port) &&
-#if	NORMA_IPC
-		    (! IP_NORMA_IS_PROXY(dest_port)) &&
-#endif	/* NORMA_IPC */
 		    ((dest_port->ip_msgcount < dest_port->ip_qlimit) ||
 		     (MACH_MSGH_BITS_REMOTE(kmsg->ikm_header.msgh_bits) ==
 					MACH_MSG_TYPE_PORT_SEND_ONCE)))
@@ -1380,28 +1358,6 @@ mach_msg_trap(msg, option, send_size, rcv_size, rcv_name, time_out, notify)
 		ip_unlock(dest_port);
 		goto slow_send;
 
-#if	NORMA_IPC
-	    norma_send:
-		/*
-		 *	Nothing is locked.  We have acquired kmsg, but
-		 *	we still need to send it and receive a reply.
-		 */
-
-		mr = norma_ipc_send(kmsg);
-		if (mr != MACH_MSG_SUCCESS) {
-			mr |= ipc_kmsg_copyout_pseudo(kmsg, space,
-						      current_map());
-
-			assert(kmsg->ikm_marequest == IMAR_NULL);
-			(void) ipc_kmsg_put(msg, kmsg,
-					    kmsg->ikm_header.msgh_size);
-			thread_syscall_return(mr);
-			/*NOTREACHED*/
-		}
-
-		goto slow_get_rcv_port;
-#endif	/* NORMA_IPC */
-
 	    kernel_send:
 		/*
 		 *	Special case: send message to kernel services.
