@@ -35,12 +35,9 @@
  *
  */
 
-#include <cpus.h>
-#include <mach_fixpri.h>
-#include <norma_ipc.h>
-
 #include <kern/ast.h>
 #include <kern/counters.h>
+#include <kern/debug.h>
 #include "cpu_number.h"
 #include <kern/queue.h>
 #include <kern/sched.h>
@@ -90,11 +87,6 @@ ast_taken()
 	if (reasons & AST_NETWORK)
 		net_ast();
 
-#if	NORMA_IPC
-	if (reasons & AST_NETIPC)
-		netipc_ast();
-#endif	/* NORMA_IPC */
-
 	/*
 	 *	Make darn sure that we don't call thread_halt_self
 	 *	or thread_block from the idle thread.
