@@ -27,15 +27,14 @@
  *	processor.c: processor and processor_set manipulation routines.
  */
 
-#include <cpus.h>
-#include <mach_fixpri.h>
-#include <mach_host.h>
+#include <string.h>
 
 #include <mach/boolean.h>
 #include <mach/policy.h>
 #include <mach/processor_info.h>
 #include <mach/vm_param.h>
 #include <kern/cpu_number.h>
+#include <kern/debug.h>
 #include <kern/lock.h>
 #include <kern/host.h>
 #include <kern/processor.h>
@@ -975,7 +974,7 @@ processor_set_things(
 				return KERN_RESOURCE_SHORTAGE;
 			}
 
-			bcopy((char *) addr, (char *) newaddr, size_needed);
+			memcpy((void *) newaddr, (void *) addr, size_needed);
 			kfree(addr, size);
 			addr = newaddr;
 		}
