@@ -32,19 +32,14 @@
  *
  */
 
-#include <cpus.h>
-#include <simple_clock.h>
-#include <mach_fixpri.h>
-#include <mach_host.h>
-#include <hw_footprint.h>
-#include <fast_tas.h>
-#include <power_save.h>
-
+#include <kern/printf.h>
 #include <mach/machine.h>
 #include <kern/ast.h>
 #include <kern/counters.h>
 #include <kern/cpu_number.h>
+#include <kern/debug.h>
 #include <kern/lock.h>
+#include <kern/mach_factor.h>
 #include <kern/macro_help.h>
 #include <kern/processor.h>
 #include <kern/queue.h>
