@@ -27,9 +27,6 @@
  * the rights to redistribute these changes.
  */
 
-#include <mach_ipc_compat.h>
-#include <net_atm.h>
-
 #include <mach/port.h>
 #include <mach/kern_return.h>
 #include <kern/syscall_sw.h>
@@ -38,7 +35,6 @@
 #include <mach/mach_traps.h>
 #include <mach/message.h>
 #include <kern/syscall_subr.h>
-#include <chips/nw_mk.h>
 
 
 /*
@@ -93,11 +89,6 @@ extern	kern_return_t	evc_wait_clear();
 extern	kern_return_t	syscall_device_write_request();
 extern	kern_return_t	syscall_device_writev_request();
 
-#ifdef FIPC 
-extern kern_return_t	syscall_fipc_send();
-extern kern_return_t	syscall_fipc_recv();
-#endif /* FIPC */
-
 mach_trap_t	mach_trap_table[] = {
 	MACH_TRAP(kern_invalid, 0),		/* 0 */		/* Unix */
 	MACH_TRAP(kern_invalid, 0),		/* 1 */		/* Unix */
@@ -205,24 +196,6 @@ mach_trap_t	mach_trap_table[] = {
 	MACH_TRAP(kern_invalid, 0),		/* 78 */
 	MACH_TRAP(kern_invalid, 0),		/* 79 */
 
-#if	NET_ATM
-	MACH_TRAP(mk_update,3),                       /* 80 */
-	MACH_TRAP(mk_lookup,2),                       /* 81 */
-	MACH_TRAP_STACK(mk_endpoint_allocate,4),      /* 82 */
-	MACH_TRAP_STACK(mk_endpoint_deallocate,1),    /* 83 */
-	MACH_TRAP(mk_buffer_allocate,2),              /* 84 */
-	MACH_TRAP(mk_buffer_deallocate,2),            /* 85 */
-	MACH_TRAP_STACK(mk_connection_open,4),        /* 86 */
-	MACH_TRAP_STACK(mk_connection_accept,3),      /* 87 */
-	MACH_TRAP_STACK(mk_connection_close,1),       /* 88 */
-	MACH_TRAP_STACK(mk_multicast_add,4),          /* 89 */
-	MACH_TRAP_STACK(mk_multicast_drop,4),         /* 90 */
-	MACH_TRAP(mk_endpoint_status,3),              /* 91 */
-	MACH_TRAP_STACK(mk_send,3),                   /* 92 */
-	MACH_TRAP_STACK(mk_receive,2),                /* 93 */
-	MACH_TRAP_STACK(mk_rpc,4),                    /* 94 */
-	MACH_TRAP_STACK(mk_select,3),                 /* 95 */
-#else	/* NET_ATM */
 	MACH_TRAP(kern_invalid, 0),                   /* 80 */
 	MACH_TRAP(kern_invalid, 0),                   /* 81 */
 	MACH_TRAP(kern_invalid, 0),		      /* 82 */
@@ -239,15 +212,9 @@ mach_trap_t	mach_trap_table[] = {
 	MACH_TRAP(kern_invalid, 0),	              /* 93 */
 	MACH_TRAP(kern_invalid, 0),                   /* 94 */
 	MACH_TRAP(kern_invalid, 0),                   /* 95 */
-#endif	/* NET_ATM */
 
-#ifdef FIPC
-	MACH_TRAP(syscall_fipc_send, 4),		      /* 96 */
-	MACH_TRAP(syscall_fipc_recv, 5),		      /* 97 */
-#else
 	MACH_TRAP(kern_invalid, 0),		      /* 96 */
 	MACH_TRAP(kern_invalid, 0),		      /* 97 */
-#endif /* FIPC */
 
 	MACH_TRAP(kern_invalid, 0),		      /* 98 */
 	MACH_TRAP(kern_invalid, 0),		      /* 99 */
