@@ -31,11 +31,7 @@
  *	Task management primitives implementation.
  */
 
-#include <mach_host.h>
-#include <mach_pcsample.h>
-#include <norma_task.h>
-#include <fast_tas.h>
-#include <net_atm.h>
+#include <string.h>
 
 #include <mach/machine/vm_types.h>
 #include <mach/vm_param.h>
@@ -43,6 +39,7 @@
 #include <mach/task_special_ports.h>
 #include <ipc/ipc_space.h>
 #include <ipc/ipc_types.h>
+#include <kern/debug.h>
 #include <kern/mach_param.h>
 #include <kern/task.h>
 #include <kern/thread.h>
@@ -54,14 +51,6 @@
 #include <vm/vm_kern.h>		/* for kernel_map, ipc_kernel_map */
 #include <machine/machspl.h>	/* for splsched */
 
-#if	NET_ATM
-#include <chips/nw_mk.h>
-#endif
-
-#if	NORMA_TASK
-#define	task_create	task_create_local
-#endif	/* NORMA_TASK */
-
 task_t	kernel_task = TASK_NULL;
 zone_t	task_zone;
 
@@ -157,10 +146,6 @@ kern_return_t task_create(
 
 	ipc_task_init(new_task, parent_task);
 
-#if	NET_ATM
-	new_task->nw_ep_owned = 0;
-#endif
-
 	new_task->total_user_time.seconds = 0;
 	new_task->total_user_time.microseconds = 0;
 	new_task->total_system_time.seconds = 0;
@@ -209,10 +194,6 @@ kern_return_t task_create(
 
 	ipc_task_enable(new_task);
 
-#if	NORMA_TASK
-	new_task->child_node = -1;
-#endif	/* NORMA_TASK */
-
 	*child_task = new_task;
 	return KERN_SUCCESS;
 }
@@ -239,14 +220,6 @@ void task_deallocate(
 	if (c != 0)
 		return;
 
-#if	NORMA_TASK
-	if (task->map == VM_MAP_NULL) {
-		/* norma placeholder task */
-		zfree(task_zone, (vm_offset_t) task);
-		return;
-	}
-#endif	/* NORMA_TASK */
-
 	eml_task_deallocate(task);
 
 	pset = task->processor_set;
@@ -291,13 +264,6 @@ kern_return_t task_terminate(
 	cur_task = current_task();
 	cur_thread = current_thread();
 
-#if	NET_ATM
-	/*
-	 *      Shut down networking.
-         */
-	mk_endpoint_collect(task);
-#endif
-
 	/*
 	 *	Deactivate task so that it can't be terminated again,
 	 *	and so lengthy operations in progress will abort.
@@ -662,7 +628,7 @@ kern_return_t task_threads(
 				return KERN_RESOURCE_SHORTAGE;
 			}
 
-			bcopy((char *) addr, (char *) newaddr, size_needed);
+			memcpy((void *) newaddr, (void *) addr, size_needed);
 			kfree(addr, size);
 			threads = (thread_t *) newaddr;
 		}
