@@ -31,24 +31,17 @@
  *	Thread management primitives implementation.
  */
 
-#include <cpus.h>
-#include <hw_footprint.h>
-#include <mach_host.h>
-#include <mach_fixpri.h>
-#include <mach_pcsample.h>
-#include <simple_clock.h>
-#include <mach_debug.h>
-#include <net_atm.h>
-
+#include <kern/printf.h>
 #include <mach/std_types.h>
 #include <mach/policy.h>
 #include <mach/thread_info.h>
 #include <mach/thread_special_ports.h>
 #include <mach/thread_status.h>
 #include <mach/time_value.h>
-#include "vm_param.h"
+#include <machine/vm_param.h>
 #include <kern/ast.h>
 #include <kern/counters.h>
+#include <kern/debug.h>
 #include <kern/ipc_tt.h>
 #include <kern/mach_param.h>
 #include <kern/processor.h>
@@ -64,12 +57,9 @@
 #include <ipc/ipc_port.h>
 #include <ipc/mach_msg.h>
 #include <machine/machspl.h>		/* for splsched */
+#include <machine/pcb.h>
 #include <machine/thread.h>		/* for MACHINE_STACK */
 
-#if	NET_ATM
-#include <chips/nw_mk.h>
-#endif
-
 thread_t active_threads[NCPUS];
 vm_offset_t active_stacks[NCPUS];
 
@@ -429,6 +419,8 @@ kern_return_t thread_create(
 
 	*new_thread = thread_template;
 
+	record_time_stamp (&new_thread->creation_time);
+
 	/*
 	 *	Initialize runtime-dependent fields
 	 */
@@ -446,10 +438,6 @@ kern_return_t thread_create(
 
 	ipc_thread_init(new_thread);
 
-#if	NET_ATM
-	new_thread->nw_ep_waited = 0;
-#endif
-
 	/*
 	 *	Find the processor set for the parent task.
 	 */
@@ -860,9 +848,6 @@ kern_return_t thread_terminate(
 	 *	reference to itself.
 	 */
 	ipc_thread_terminate(thread);
-#if	NET_ATM
-	mk_waited_collect(thread);
-#endif
 	thread_deallocate(thread);
 	return KERN_SUCCESS;
 }
@@ -901,9 +886,6 @@ thread_force_terminate(
 
 	(void) thread_halt(thread, TRUE);
 	ipc_thread_terminate(thread);
-#if	NET_ATM
-	mk_waited_collect(thread);
-#endif
 
 #if	MACH_HOST
 	thread_unfreeze(thread);
@@ -1145,9 +1127,6 @@ void	thread_halt_self(void)
 		 *	reaper thread.
 		 */
 		ipc_thread_terminate(thread);
-#if	NET_ATM
-		mk_waited_collect(thread);
-#endif
 
 		thread_hold(thread);
 
@@ -1473,7 +1452,11 @@ kern_return_t thread_info(
 	if (flavor == THREAD_BASIC_INFO) {
 	    register thread_basic_info_t	basic_info;
 
-	    if (*thread_info_count < THREAD_BASIC_INFO_COUNT) {
+	    /* Allow *thread_info_count to be one smaller than the
+	       usual amount, because creation_time is a new member
+	       that some callers might not know about. */
+
+	    if (*thread_info_count < THREAD_BASIC_INFO_COUNT - 1) {
 		return KERN_INVALID_ARGUMENT;
 	    }
 
@@ -1496,6 +1479,7 @@ kern_return_t thread_info(
 			&basic_info->system_time);
 	    basic_info->base_priority	= thread->priority;
 	    basic_info->cur_priority	= thread->sched_pri;
+	    basic_info->creation_time  = thread->creation_time;
 
 	    /*
 	     *	To calculate cpu_usage, first correct for timer rate,
@@ -1547,7 +1531,8 @@ kern_return_t thread_info(
 	    thread_unlock(thread);
 	    splx(s);
 
-	    *thread_info_count = THREAD_BASIC_INFO_COUNT;
+	    if (*thread_info_count > THREAD_BASIC_INFO_COUNT)
+	      *thread_info_count = THREAD_BASIC_INFO_COUNT;
 	    return KERN_SUCCESS;
 	}
 	else if (flavor == THREAD_SCHED_INFO) {
