@@ -34,12 +34,6 @@
 #ifndef	_KERN_THREAD_H_
 #define _KERN_THREAD_H_
 
-#include <mach_ipc_compat.h>
-#include <hw_footprint.h>
-#include <mach_fixpri.h>
-#include <mach_host.h>
-#include <net_atm.h>
-
 #include <mach/boolean.h>
 #include <mach/thread_info.h>
 #include <mach/thread_status.h>
@@ -220,10 +214,6 @@ struct thread {
 #if	NCPUS > 1
 	processor_t	last_processor; /* processor this last ran on */
 #endif	/* NCPUS > 1 */
-
-#if	NET_ATM
-	nw_ep_owned_t   nw_ep_waited;
-#endif	/* NET_ATM */
 };
 
 /* typedef of thread_t is in kern/kern_types.h */
