@@ -24,10 +24,12 @@
  * the rights to redistribute these changes.
  */
 
-#include <mach_kdb.h>
 /*
  * xpr silent tracing circular buffer.
  */
+#include <string.h>
+
+#include <kern/debug.h>
 #include <kern/xpr.h>
 #include <kern/lock.h>
 #include "cpu_number.h"
@@ -113,7 +115,7 @@ void xprbootstrap()
 		 *	the previous buffer contents.
 		 */
 
-		bzero((char *) addr, size);
+		memset((char *) addr, 0, size);
 	}
 
 	xprbase = (struct xprbuf *) addr;
