@@ -34,7 +34,11 @@
  *	data blocks for which quick allocation/deallocation is possible.
  */
 
+#include <string.h>
+
+#include <kern/debug.h>
 #include <kern/macro_help.h>
+#include <kern/printf.h>
 #include <kern/sched.h>
 #include <kern/time_out.h>
 #include <kern/zalloc.h>
@@ -42,7 +46,6 @@
 #include <vm/vm_kern.h>
 #include <machine/machspl.h>
 
-#include <mach_debug.h>
 #if	MACH_DEBUG
 #include <mach/kern_return.h>
 #include <mach/machine/vm_types.h>
@@ -943,7 +946,7 @@ kern_return_t host_zone_info(host, namesp, namesCntp, infop, infoCntp)
 		used = max_zones * sizeof *names;
 
 		if (used != names_size)
-			bzero((char *) (names_addr + used), names_size - used);
+			memset((char *) (names_addr + used), 0, names_size - used);
 
 		kr = vm_map_copyin(ipc_kernel_map, names_addr, names_size,
 				   TRUE, &copy);
@@ -960,7 +963,7 @@ kern_return_t host_zone_info(host, namesp, namesCntp, infop, infoCntp)
 		used = max_zones * sizeof *info;
 
 		if (used != info_size)
-			bzero((char *) (info_addr + used), info_size - used);
+			memset((char *) (info_addr + used), 0, info_size - used);
 
 		kr = vm_map_copyin(ipc_kernel_map, info_addr, info_size,
 				   TRUE, &copy);
