@@ -59,7 +59,7 @@
 #include <device/device_types.h>
 #include <device/device_port.h>
 #include <device/disk_status.h>
-#include "device_reply.h"
+#include <device/device_reply.user.h>
 
 #include <linux_emul.h>
 
@@ -354,22 +354,17 @@ struct buffer_head *
 getblk (kdev_t dev, int block, int size)
 {
   struct buffer_head *bh;
-  static struct buffer_head bhead;
 
   assert (size <= PAGE_SIZE);
 
-  if (! linux_auto_config)
-    bh = (struct buffer_head *) kalloc (sizeof (struct buffer_head));
-  else
-    bh = &bhead;
+  bh = (struct buffer_head *) kalloc (sizeof (struct buffer_head));
   if (bh)
     {
       memset (bh, 0, sizeof (struct buffer_head));
       bh->b_data = alloc_buffer (size);
       if (! bh->b_data)
 	{
-	  if (! linux_auto_config)
-	    kfree ((vm_offset_t) bh, sizeof (struct buffer_head));
+	  kfree ((vm_offset_t) bh, sizeof (struct buffer_head));
 	  return NULL;
 	}
       bh->b_dev = dev;
@@ -385,8 +380,7 @@ void
 __brelse (struct buffer_head *bh)
 {
   free_buffer (bh->b_data, bh->b_size);
-  if (! linux_auto_config)
-    kfree ((vm_offset_t) bh, sizeof (*bh));
+  kfree ((vm_offset_t) bh, sizeof (*bh));
 }
 
 /* Allocate a buffer of SIZE bytes and fill it with data
@@ -550,7 +544,6 @@ rdwr_partial (int rw, kdev_t dev, loff_t *off,
     {
       o = *off & BMASK;
       c = bh->b_size - o;
-      assert (*resid <= c);
       if (c > *resid)
 	c = *resid;
       if (rw == READ)
@@ -595,7 +588,6 @@ rdwr_full (int rw, kdev_t dev, loff_t *off, char **buf, int *resid, int bshift)
   struct buffer_head bhead[MAX_BUF], *bh, *bhp[MAX_BUF];
 
   assert ((*off & BMASK) == 0);
-  assert (*resid >= bsize);
 
   nbuf = *resid >> bshift;
   blk = *off >> bshift;
@@ -961,7 +953,7 @@ init_partition (struct name_map *np, kdev_t *dev,
       if (ds->fops->open && (*ds->fops->open) (&d->inode, &d->file))
 	continue;
       lp = read_bsd_label (d->inode.i_rdev);
-      if (! lp)
+      if (! lp && gd->part[MINOR (d->inode.i_rdev)].nr_sects > PDLOCATION)
 	lp = read_vtoc (d->inode.i_rdev);
       if (ds->fops->release)
 	(*ds->fops->release) (&d->inode, &d->file);
@@ -1654,8 +1646,9 @@ device_get_status (void *d, dev_flavor_t flavor, dev_status_t status,
       else
 	{
 	  assert (blk_size[MAJOR (bd->dev)]);
-	  (status[DEV_GET_RECORDS_DEVICE_RECORDS]
-	   = blk_size[MAJOR (bd->dev)][MINOR (bd->dev)]);
+	  status[DEV_GET_RECORDS_DEVICE_RECORDS]
+	    = (blk_size[MAJOR (bd->dev)][MINOR (bd->dev)]
+	       << (BLOCK_SIZE_BITS - 9));
 	}
       /* It would be nice to return the block size as reported by
 	 the driver, but a lot of user level code assumes the sector
