@@ -20,50 +20,37 @@
  * General Public License for more details.
  *
  *
- * $Id: aha152x.c,v 1.1 1999/04/26 05:54:09 tb Exp $
+ * $Id: aha152x.c,v 1.1.4.1 2006/10/08 13:52:36 tschwinge Exp $
  *
  * $Log: aha152x.c,v $
- * Revision 1.1  1999/04/26 05:54:09  tb
- * 1998-11-30  OKUJI Yoshinori  <okuji@kuicr.kyoto-u.ac.jp>
+ * Revision 1.1.4.1  2006/10/08 13:52:36  tschwinge
+ * 2006-10-08  Thomas Schwinge  <tschwinge@gnu.org>
  *
- * 	Clean up linux emulation code to make it architecture-independent
- * 	as much as possible.
+ * 	* linux/dev/drivers/scsi/aha152x.c: Move file...
+ * 	* linux/src/drivers/scsi/aha152x.c: ... here.
  *
- * 	* linux: Renamed from linuxdev.
- * 	* Makefile.in (objfiles): Add linux.o instead of linuxdev.o.
- * 	(MAKE): New variable. Used for the linux.o target.
- * 	* configure.in: Add AC_CHECK_TOOL(MAKE, make).
- * 	* i386/i386/spl.h: Include <i386/ipl.h>, for compatibility with
- * 	OSF Mach 3.0. Suggested by Elgin Lee <ehl@funghi.com>.
- * 	* linux/src: Renamed from linux/linux.
- * 	* linux/dev: Renamed from linux/mach.
- * 	* linux/Drivers.in (AC_INIT): Use dev/include/linux/autoconf.h,
- * 	instead of mach/include/linux/autoconf.h.
- * 	* Makefile.in (all): Target ../linux.o instead of ../linuxdev.o.
- * 	* linux/dev/drivers/block/genhd.c: Include <machine/spl.h> instead
- * 	of <i386/ipl.h>.
- * 	* linux/dev/drivers/net/auto_irq.c: Remove unneeded header files,
- * 	<i386/ipl.h> and <i386/pic.h>.
- * 	* linux/dev/init/main.c: Many i386-dependent codes moved to ...
- * 	* linux/dev/arch/i386/irq.c: ... here.
- * 	* linux/dev/arch/i386/setup.c: New file.
- * 	* linux/dev/arch/i386/linux_emul.h: Likewise.
- * 	* linux/dev/arch/i386/glue/timer.c: Merged into sched.c.
- * 	* linux/dev/arch/i386/glue/sched.c: Include <machine/spl.h> instead
- * 	of <i386/ipl.h>, and moved to ...
- * 	* linux/dev/kernel/sched.c: ... here.
- * 	* linux/dev/arch/i386/glue/block.c: Include <machine/spl.h> and
- * 	<linux_emul.h>, instead of i386-dependent header files, and
- * 	moved to ...
- * 	* linux/dev/glue/blocl.c: ... here.
- * 	* linux/dev/arch/i386/glue/net.c: Include <machine/spl.h> and
- * 	<linux_emul.h>, instead of i386-dependent header files, and
- * 	moved to ...
- * 	* linux/dev/glue/net.c: ... here.
- * 	* linux/dev/arch/i386/glue/misc.c: Remove `x86' and moved to ...
- * 	* linux/dev/glue/misc.c: ... here.
- * 	* linux/dev/arch/i386/glue/kmem.c: Moved to ...
- * 	* linux/dev/glue/kmem.c: ... here.
+ * Revision 1.1  1999/04/26 05:44:22  tb
+ * 1999-04-12  OKUJI Yoshinori  <okuji@kuicr.kyoto-u.ac.jp>
+ *
+ * 	* linux/dev/drivers/block/ide.c (init_hwif_data) [MACH]: Print Mach
+ * 	device name instead of Linux one.
+ * 	* linux/dev/drivers/block/genhd.c (disk_name): Likewise.
+ * 	* linux/dev/drivers/scsi/sd.c (sd_init_onedisk): Likewise.
+ * 	(sd_detect): Likewise.
+ * 	* linux/dev/drivers/sr.c (sr_detect): Likewise.
+ * 	(get_sectorsize): Likewise.
+ *
+ * 1999-02-04  OKUJI Yoshinori  <okuji@kuicr.kyoto-u.ac.jp>
+ *
+ * 	* device/kmsg.c (kmsginit): Add a missing semicolon.
+ * 	(kmsggetstat): Fix typos,
+ * 	DEV_GET_DEVICE_SIZE -> DEV_GET_SIZE_DEVICE_SIZE and
+ * 	DEV_GET_RECORD_SIZE -> DEV_GET_SIZE_RECORD_SIZE.
+ * 	(kmsg_putchar): Fix a typo kmsg_done_init -> kmsg_init_done.
+ * 	* linux/dev/glue/block.c (device_get_status): Allocate a hd_geometry
+ * 	on the stack.
+ * 	* linux/dev/drivers/block/ide.c: New file.
+ * 	* linux/dev/drivers/scsi/sd_ioctl.c: New file.
  *
  * Revision 1.18  1996/09/07 20:10:40  fischer
  * - fixed can_queue handling (multiple outstanding commands working again)
@@ -362,6 +349,10 @@
 
  **************************************************************************/
 
+#ifdef MACH
+#define AUTOCONF	1
+#endif
+
 #ifdef PCMCIA
 #define MODULE
 #endif
