@@ -47,8 +47,8 @@
 #include <mach/vm_prot.h>
 #include <mach/message.h>
 
-#include "memory_object_user.h"
-#include "memory_object_default.h"
+#include <vm/memory_object_user.user.h>
+#include <vm/memory_object_default.user.h>
 
 /*
  *	Implementation dependencies:
@@ -57,21 +57,16 @@
 #include <vm/vm_page.h>
 #include <vm/vm_pageout.h>
 #include <vm/pmap.h>		/* For copy_to_phys, pmap_clear_modify */
+#include <kern/debug.h>		/* For panic() */
 #include <kern/thread.h>		/* For current_thread() */
 #include <kern/host.h>
 #include <vm/vm_kern.h>		/* For kernel_map, vm_move */
 #include <vm/vm_map.h>		/* For vm_map_pageable */
 #include <ipc/ipc_port.h>
 
-#include <norma_vm.h>
-#include <norma_ipc.h>
-#if	NORMA_VM
-#include <norma/xmm_server_rename.h>
-#endif	NORMA_VM
-#include <mach_pagemap.h>
 #if	MACH_PAGEMAP
-#include <vm/vm_external.h>	
-#endif	MACH_PAGEMAP
+#include <vm/vm_external.h>
+#endif	/* MACH_PAGEMAP */
 
 typedef	int		memory_object_lock_result_t; /* moved from below */
 
@@ -86,7 +81,6 @@ decl_simple_lock_data(,memory_manager_default_lock)
  *		argument conversion. Explicit deallocation is necessary.
  */
 
-#if	!NORMA_VM
 /*
  *	If successful, destroys the map copy object.
  */
@@ -102,7 +96,6 @@ kern_return_t memory_object_data_provided(object, offset, data, data_cnt,
 					 data_cnt, lock_value, FALSE, IP_NULL,
 					 0);
 }
-#endif	!NORMA_VM
 
 
 kern_return_t memory_object_data_supply(object, offset, data_copy, data_cnt,
@@ -382,7 +375,7 @@ kern_return_t memory_object_data_unavailable(object, offset, size)
 {
 #if	MACH_PAGEMAP
 	vm_external_t	existence_info = VM_EXTERNAL_NULL;
-#endif	MACH_PAGEMAP
+#endif	/* MACH_PAGEMAP */
 
 	if (object == VM_OBJECT_NULL)
 		return(KERN_INVALID_ARGUMENT);
@@ -391,11 +384,11 @@ kern_return_t memory_object_data_unavailable(object, offset, size)
 		return(KERN_INVALID_ARGUMENT);
 
 #if	MACH_PAGEMAP
-	if ((offset == 0) && (size > VM_EXTERNAL_LARGE_SIZE) && 
+	if ((offset == 0) && (size > VM_EXTERNAL_LARGE_SIZE) &&
 	    (object->existence_info == VM_EXTERNAL_NULL)) {
 		existence_info = vm_external_create(VM_EXTERNAL_SMALL_SIZE);
 	}
-#endif	MACH_PAGEMAP
+#endif	/* MACH_PAGEMAP */
 
 	vm_object_lock(object);
 #if	MACH_PAGEMAP
@@ -407,7 +400,7 @@ kern_return_t memory_object_data_unavailable(object, offset, size)
 		vm_object_deallocate(object);
 		return(KERN_SUCCESS);
 	}
-#endif	MACH_PAGEMAP
+#endif	/* MACH_PAGEMAP */
 	offset -= object->paging_offset;
 
 	while (size != 0) {
@@ -500,7 +493,7 @@ memory_object_lock_result_t memory_object_lock_page(m, should_return,
 		 *		    Page is not dirty [2 checks] AND (
 		 *		        Page is not precious OR
 		 *			No request to return precious pages ))
-		 *		      
+		 *
 		 *	Now isn't that straightforward and obvious ?? ;-)
 		 *
 		 * XXX	This doesn't handle sending a copy of a wired
@@ -896,9 +889,8 @@ MACRO_END
 	return (KERN_SUCCESS);
 }
 
-#if	!NORMA_VM
 /*
- *	Old version of memory_object_lock_request.  
+ *	Old version of memory_object_lock_request.
  */
 kern_return_t
 xxx_memory_object_lock_request(object, offset, size,
@@ -924,8 +916,7 @@ xxx_memory_object_lock_request(object, offset, size,
 		      should_return, should_flush, prot,
 		      reply_to, reply_to_type));
 }
-#endif	!NORMA_VM
-	  
+
 kern_return_t
 memory_object_set_attributes_common(object, object_ready, may_cache,
 				    copy_strategy, use_old_pageout)
@@ -989,8 +980,6 @@ memory_object_set_attributes_common(object, object_ready, may_cache,
 	return(KERN_SUCCESS);
 }
 
-#if	!NORMA_VM
-
 /*
  * XXX	rpd claims that reply_to could be obviated in favor of a client
  * XXX	stub that made change_attributes an RPC.  Need investigation.
@@ -1052,7 +1041,6 @@ kern_return_t	memory_object_ready(object, may_cache, copy_strategy)
 						   may_cache, copy_strategy,
 						   FALSE);
 }
-#endif	!NORMA_VM
 
 kern_return_t	memory_object_get_attributes(object, object_ready,
 						may_cache, copy_strategy)
