@@ -32,15 +32,13 @@
  *
  *	Page fault handling module.
  */
-#include <mach_pagemap.h>
-#include <mach_kdb.h>
-#include <mach_pcsample.h>
-
 
+#include <kern/printf.h>
 #include <vm/vm_fault.h>
 #include <mach/kern_return.h>
 #include <mach/message.h>	/* for error codes */
 #include <kern/counters.h>
+#include <kern/debug.h>
 #include <kern/thread.h>
 #include <kern/sched_prim.h>
 #include <vm/vm_map.h>
@@ -51,7 +49,7 @@
 #include <vm/vm_pageout.h>
 #include <mach/vm_param.h>
 #include <mach/memory_object.h>
-#include "memory_object_user.h"
+#include <vm/memory_object_user.user.h>
 				/* For memory_object_data_{request,unlock} */
 #include <kern/mach_param.h>
 #include <kern/macro_help.h>
@@ -100,7 +98,7 @@ boolean_t	software_reference_bits = TRUE;
 
 #if	MACH_KDB
 extern struct db_watchpoint *db_watchpoint_list;
-#endif	MACH_KDB
+#endif	/* MACH_KDB */
 
 /*
  *	Routine:	vm_fault_init
@@ -286,7 +284,7 @@ vm_fault_return_t vm_fault_page(first_object, first_offset,
 		 *	so that the watchpoint code notices the access.
 		 */
 	    || db_watchpoint_list
-#endif	MACH_KDB
+#endif	/* MACH_KDB */
 	    ) {
 		/*
 		 *	If we aren't asking for write permission,
@@ -443,7 +441,7 @@ vm_fault_return_t vm_fault_page(first_object, first_offset,
 					 * need to allocate a real page.
 					 */
 
-					real_m = vm_page_grab();
+					real_m = vm_page_grab(!object->internal);
 					if (real_m == VM_PAGE_NULL) {
 						vm_fault_cleanup(object, first_m);
 						return(VM_FAULT_MEMORY_SHORTAGE);
@@ -481,7 +479,7 @@ vm_fault_return_t vm_fault_page(first_object, first_offset,
 					vm_page_zero_fill(m);
 
 					vm_stat_sample(SAMPLED_PC_VM_ZFILL_FAULTS);
-					
+
 					vm_stat.zero_fill_count++;
 					vm_object_lock(object);
 					pmap_clear_modify(m->phys_addr);
@@ -519,7 +517,7 @@ vm_fault_return_t vm_fault_page(first_object, first_offset,
 				if ((access_required & m->unlock_request) != access_required) {
 					vm_prot_t	new_unlock_request;
 					kern_return_t	rc;
-					
+
 					if (!object->pager_ready) {
 						vm_object_assert_wait(object,
 							VM_OBJECT_EVENT_PAGER_READY,
@@ -581,7 +579,7 @@ vm_fault_return_t vm_fault_page(first_object, first_offset,
 #if	MACH_PAGEMAP
 			&& (vm_external_state_get(object->existence_info, offset + object->paging_offset) !=
 			 VM_EXTERNAL_STATE_ABSENT)
-#endif	MACH_PAGEMAP
+#endif	/* MACH_PAGEMAP */
 			 ;
 
 		if ((look_for_page || (object == first_object))
@@ -625,7 +623,7 @@ vm_fault_return_t vm_fault_page(first_object, first_offset,
 				 *	won't block for pages.
 				 */
 
-				if (m->fictitious && !vm_page_convert(m)) {
+				if (m->fictitious && !vm_page_convert(m, FALSE)) {
 					VM_PAGE_FREE(m);
 					vm_fault_cleanup(object, first_m);
 					return(VM_FAULT_MEMORY_SHORTAGE);
@@ -664,16 +662,16 @@ vm_fault_return_t vm_fault_page(first_object, first_offset,
 			vm_stat.pageins++;
 		    	vm_stat_sample(SAMPLED_PC_VM_PAGEIN_FAULTS);
 
-			if ((rc = memory_object_data_request(object->pager, 
+			if ((rc = memory_object_data_request(object->pager,
 				object->pager_request,
-				m->offset + object->paging_offset, 
+				m->offset + object->paging_offset,
 				PAGE_SIZE, access_required)) != KERN_SUCCESS) {
 				if (rc != MACH_SEND_INTERRUPTED)
 					printf("%s(0x%x, 0x%x, 0x%x, 0x%x, 0x%x) failed, %d\n",
 						"memory_object_data_request",
 						object->pager,
 						object->pager_request,
-						m->offset + object->paging_offset, 
+						m->offset + object->paging_offset,
 						PAGE_SIZE, access_required, rc);
 				/*
 				 *	Don't want to leave a busy page around,
@@ -689,7 +687,7 @@ vm_fault_return_t vm_fault_page(first_object, first_offset,
 					VM_FAULT_INTERRUPTED :
 					VM_FAULT_MEMORY_ERROR);
 			}
-			
+
 			/*
 			 * Retry with same object/offset, since new data may
 			 * be in a different page (i.e., m is meaningless at
@@ -742,7 +740,7 @@ vm_fault_return_t vm_fault_page(first_object, first_offset,
 			assert(m->object == object);
 			first_m = VM_PAGE_NULL;
 
-			if (m->fictitious && !vm_page_convert(m)) {
+			if (m->fictitious && !vm_page_convert(m, !object->internal)) {
 				VM_PAGE_FREE(m);
 				vm_fault_cleanup(object, VM_PAGE_NULL);
 				return(VM_FAULT_MEMORY_SHORTAGE);
@@ -789,7 +787,7 @@ vm_fault_return_t vm_fault_page(first_object, first_offset,
 	assert((first_m == VM_PAGE_NULL) ||
 		(first_m->busy && !first_m->absent &&
 		 !first_m->active && !first_m->inactive));
-#endif	EXTRA_ASSERTIONS
+#endif	/* EXTRA_ASSERTIONS */
 
 	/*
 	 *	If the page is being written, but isn't
@@ -828,7 +826,7 @@ vm_fault_return_t vm_fault_page(first_object, first_offset,
 			/*
 			 *	Allocate a page for the copy
 			 */
-			copy_m = vm_page_grab();
+			copy_m = vm_page_grab(!first_object->internal);
 			if (copy_m == VM_PAGE_NULL) {
 				RELEASE_PAGE(m);
 				vm_fault_cleanup(object, first_m);
@@ -983,7 +981,7 @@ vm_fault_return_t vm_fault_page(first_object, first_offset,
 			 */
 
 			vm_page_copy(m, copy_m);
-			
+
 			/*
 			 *	If the old page was in use by any users
 			 *	of the copy-object, it must be removed
@@ -1059,7 +1057,7 @@ vm_fault_return_t vm_fault_page(first_object, first_offset,
 			 *	wait result].  Can't turn off the page's
 			 *	busy bit because we're not done with it.
 			 */
-			 
+
 			if (m->wanted) {
 				m->wanted = FALSE;
 				thread_wakeup_with_result((event_t) m,
@@ -1749,7 +1747,7 @@ kern_return_t vm_fault_wire_fast(map, va, entry)
 
 	/*
 	 *	Wire the page down now.  All bail outs beyond this
-	 *	point must unwire the page.  
+	 *	point must unwire the page.
 	 */
 
 	vm_page_lock_queues();
@@ -1774,7 +1772,7 @@ kern_return_t vm_fault_wire_fast(map, va, entry)
 	/*
 	 *	Put this page into the physical map.
 	 *	We have to unlock the object because pmap_enter
-	 *	may cause other faults.   
+	 *	may cause other faults.
 	 */
 	vm_object_unlock(object);
 
@@ -1865,7 +1863,7 @@ kern_return_t	vm_fault_copy(
 {
 	vm_page_t		result_page;
 	vm_prot_t		prot;
-	
+
 	vm_page_t		src_page;
 	vm_page_t		src_top_page;
 
@@ -2020,7 +2018,7 @@ kern_return_t	vm_fault_copy(
 	RETURN(KERN_SUCCESS);
 #undef	RETURN
 
-	/*NOTREACHED*/	
+	/*NOTREACHED*/
 }
 
 
@@ -2179,4 +2177,4 @@ vm_fault_return_t vm_fault_page_overwrite(dst_object, dst_offset, result_page)
 #undef	DISCARD_PAGE
 }
 
-#endif	notdef
+#endif	/* notdef */
