@@ -34,9 +34,6 @@
 #ifndef	_VM_VM_OBJECT_H_
 #define _VM_VM_OBJECT_H_
 
-#include <mach_pagemap.h>
-#include <norma_vm.h>
-
 #include <mach/kern_return.h>
 #include <mach/boolean.h>
 #include <mach/memory_object.h>
@@ -46,6 +43,7 @@
 #include <kern/queue.h>
 #include <kern/lock.h>
 #include <kern/assert.h>
+#include <kern/debug.h>
 #include <kern/macro_help.h>
 #include <vm/pmap.h>
 
@@ -53,11 +51,7 @@
 #include <vm/vm_external.h>
 #endif	/* MACH_PAGEMAP */
 
-#if	NORMA_VM
-typedef struct xmm_obj *	pager_request_t;
-#else	/* NORMA_VM */
 typedef struct ipc_port *	pager_request_t;
-#endif	/* NORMA_VM */
 #define	PAGER_REQUEST_NULL	((pager_request_t) 0)
 
 /*
