@@ -34,16 +34,14 @@
  *	The proverbial page-out daemon.
  */
 
-#include <mach_pagemap.h>
-#include <norma_vm.h>
-
 #include <mach/mach_types.h>
 #include <mach/memory_object.h>
-#include "memory_object_default.h"
-#include "memory_object_user.h"
+#include <vm/memory_object_default.user.h>
+#include <vm/memory_object_user.user.h>
 #include <mach/vm_param.h>
 #include <mach/vm_statistics.h>
 #include <kern/counters.h>
+#include <kern/debug.h>
 #include <kern/thread.h>
 #include <vm/pmap.h>
 #include <vm/vm_map.h>
@@ -190,14 +188,6 @@ unsigned int vm_pageout_inactive_dirty = 0;	/* debugging */
 unsigned int vm_pageout_inactive_double = 0;	/* debugging */
 unsigned int vm_pageout_inactive_cleaned_external = 0;
 
-#if	NORMA_VM
-/*
- * Define them here, since they won't be defined by memory_object_user.h.
- */
-extern kern_return_t memory_object_data_initialize();
-extern kern_return_t memory_object_data_write();
-#endif	/* NORMA_VM */
-
 /*
  *	Routine:	vm_pageout_setup
  *	Purpose:
