@@ -32,15 +32,18 @@
  *
  *	Resident memory management module.
  */
-#include <cpus.h>
+
+#include <kern/printf.h>
+#include <string.h>
 
 #include <mach/vm_prot.h>
 #include <kern/counters.h>
+#include <kern/debug.h>
 #include <kern/sched_prim.h>
 #include <kern/task.h>
 #include <kern/thread.h>
 #include <mach/vm_statistics.h>
-#include "vm_param.h"
+#include <machine/vm_param.h>
 #include <kern/xpr.h>
 #include <kern/zalloc.h>
 #include <vm/pmap.h>
@@ -49,7 +52,6 @@
 #include <vm/vm_pageout.h>
 #include <vm/vm_kern.h>
 
-#include <mach_vm_debug.h>
 #if	MACH_VM_DEBUG
 #include <mach/kern_return.h>
 #include <mach_debug/hash_info.h>
@@ -961,7 +963,7 @@ vm_page_grab_contiguous_pages(
 	} else
 		alloc_size = 0;
 
-	bzero(bits, size);
+	memset(bits, 0, size);
 
 	/*
 	 * A very large granularity call, its rare so that is ok
@@ -1483,7 +1485,7 @@ vm_page_info(
 }
 #endif	/* MACH_VM_DEBUG */
 
-#include <mach_kdb.h>
+
 #if	MACH_KDB
 #define	printf	kdbprintf
 
